% endogenous variables

var fyt fkt fnt fct fit fgt fnut fxt fmt fut fvt fqt fst fkpt

fGammat frt frkt fqkt fpwt fat fwt fbt fthetat

e_bt e_it e_zt e_gt ;


% exogenous variables

varexo innovation_bt innovation_it innovation_zt 

innovation_gt ;


parameters alpha beta delta sigma rho yg s csi psinu etak h bb eta 
epsilonp epsilong rhos gammaz rhob rhoi rhoz rhog sigmab sigmai sigmaz 
sigmag rk x n u qk k a y i g pw fkappa fw fb fc fyc yi ynu fyx htilda etanu 
betatilda kappalambda fH;         


alpha = 0.33;
beta = 0.99;
delta = 0.025;
sigma = 0.5;
rho = 0.895;
yg= 0.2;
s = 0.95;
csi = 10;
%-----------------------estimated parameters
psinu = 0.5;
etak = 4;
h = 0.5;
bb = 0.5;
eta = 0.5;
epsilonp = 1.15;
%to make it consistent with 0.2 ss gov't share
epsilong = 1.25;
rhos = 0.75;
gammaz = 1; %1.004;
rhob = 0.5;
rhoi = 0.5;
rhoz = 0.5;
rhog = 0.5;
sigmab = 0;
sigmai = 0;
sigmaz = 0.15;
sigmag = 0;



% model equations

model(linear);

% technology
fyt=alpha*fkt+(1-alpha)*fnt;

% resource constraint 
fyt=fyc*fct+yi*fit+yg*fgt+ynu*fnut+fyx*(2*fxt+fnt(-1));

% matching
fmt=sigma*fut+(1-sigma)*fvt;

% employment dynamics
fnt=fnt(-1)+(1-rho)*fxt;

% transition probabilities
fqt=fmt-fvt;
fst=fmt-fut;

% unemployment
fut=-(n/u)*fnt(-1);

% effective capital
fkt+e_zt=fnut+fkpt(-1);

% physical capital dynamics (here shock normalized)
fkpt=(1-delta)/gammaz*(fkpt(-1)-e_zt)+(1-(1-delta)/gammaz)*fit+e_it;

% aggregate vacancies
fxt=fqt+fvt-fnt(-1);

% consumption-saving
0=fGammat(+1)+frt-e_zt(+1);

% marginal utility
fGammat = (htilda*(fct(-1)-e_zt)-(1+beta*htilda^2)*fct+beta*htilda*(fct(+1)+e_zt(+1))+(1-htilda)*(e_bt-beta*htilda*e_bt(+1)))/((1-htilda)*(1-beta*htilda))-(htilda*(fct(-2)-e_zt(-1))-(1+beta*htilda^2)*fct(-1)+beta*htilda*(fct+e_zt)+(1-htilda)*(e_bt(-1)-beta*htilda*e_bt))/((1-htilda)*(1-beta*htilda));

% capital utilization
fnut=etanu*frkt;

% investment (here I use normalized shock, but adjusted)
fit=1/(1+beta)*(fit(-1)-e_zt)+1/(etak*gammaz^2)*1/(1+beta)*fqkt+1/(1-(1-delta)/gammaz)*e_it+beta/(1+beta)*(fit(+1)+e_zt(+1));   

% capital renting
fyt-fkt=frkt;

% tobin's q    
fqkt=betatilda*(1-delta)*fqkt(+1)+(1-betatilda*(1-delta))*frkt(+1)-frt;

% marginal product of labor
fat=fyt-fnt;

% aggregate hiring rate  
fxt=((fkappa*x)^(-1)*pw*a)*fat-fkappa*fw*fwt+kappalambda*fGammat(+1)+beta*fxt(+1);

% spillover free target wage (consider only e_wt, remove e_etat)
fwt=(eta*a*pw/fw)*fat+((1-eta)*s*beta*fH/fw+eta*beta*fkappa*x^2/fw)*fxt(+1)+(1-eta)*s*beta*fH/fw*fst(+1)+(1-eta)*fb/fw*fbt+(eta*beta*fkappa*x^2/fw*1/2+(1-eta)*s*beta*fH/fw)*fGammat(+1);

% government spending
fgt=fyt+(1-yg)/yg*e_gt;

% market tightness 
fthetat=fvt-fut;

% benefits
fbt=fkpt;

% constant markup
fpwt=0;
 

%------------------- shocks

% preferences
e_bt=rhob*e_bt(-1)+innovation_bt;

% investment 
e_it=rhoi*e_it(-1)+innovation_it;

% labour productivity    
e_zt=rhoz*e_zt(-1)+innovation_zt;

% govenrment spendings    
e_gt=rhog*e_gt(-1)+innovation_gt;


end;


shocks;

var innovation_zt = sigmaz^2 ;     
var innovation_it = sigmai^2;
var innovation_gt = sigmag^2 ;
var innovation_bt = sigmab^2 ;



end; 



check;
resid(1);
steady;


stoch_simul(linear, irf=100, periods=500) ;  
